@@ -5,7 +5,7 @@
 #include "kmeanspp.h"
 #include "rand.h"
 
-int binary_search_d(double key, double * array, int len)
+static int binary_search_d(double key, double * array, int len)
 {
     int a = 0, b = len - 1;
     while (a != b)
@@ -57,6 +57,7 @@ int kmeanspp(struct cec_matrix * X, struct cec_matrix * C)
 	double n_sum = r * sums[m - 1];
 	int idx = binary_search_d(n_sum, sums, m);
 	array_copy(cec_matrix_row(X, idx), cec_matrix_row(C, i), n);
+	
 	for (int j = 1; j < m; j++)
 	{
 	    double dist = dist2(cec_matrix_row(X, j), cec_matrix_row(C, i), n);
